# tree-sitter-iml

- Based on [tree-sitter-ocaml](https://github.com/tree-sitter/tree-sitter-ocaml) with additional grammar support for [IML](https://docs.imandra.ai/imandrax/)-specific structures.
- `iml-query/` directory contains a Python library for parsing, querying, and manipulating IML files using this grammar.
- IML grammar extensions are in `grammars/iml/`
- Example IML files can be found in `iml_examples/`
